<?php
/**
 * The template for displaying Archive pages.
 *
 * Used to display archive-type pages if nothing more specific matches a query.
 * For example, puts together date-based pages if no date.php file exists.
 *
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage MikeGen
 * @since MikeGen 1.0
 */

get_header(); ?>

<div id="content" role="main">

	<?php
	/* Queue the first post, that way we know
	 * what date we're dealing with (if that is the case).
	 *
	 * We reset this later so we can run the loop
	 * properly with a call to rewind_posts().
	 */
	if ( have_posts() ): the_post(); endif; ?>

	<h1 class="page-title">
		<?php if ( is_day() ) : ?>
			<?php echo get_the_date(); ?>
		<?php elseif ( is_month() ) : ?>
			<?php echo get_the_date('F Y'); ?>
		<?php elseif ( is_year() ) : ?>
			<?php echo get_the_date('Y'); ?>
		<?php elseif ( is_category() ) : ?>
			<?php single_cat_title(); ?>
		<?php elseif ( is_tag() ) : ?>	
			<?php single_tag_title(); ?>
		<?php elseif ( is_author() ) : ?>
			<?php the_author(); ?>
		<?php else : ?>
			<?php echo __( 'Archives', 'mikegen' ); ?>
		<?php endif; ?>
	</h1>
	
	<?php if ( is_category() ) : ?>
	
		<?php 
		$category_description = category_description();
		if ( ! empty( $category_description ) ) : ?>
			<div class="archive-meta"><?php printf(__($category_description )); ?></div>
		<?php endif; ?>
		
	<?php elseif ( is_author() ) : ?>
	
		<?php if ( get_the_author_meta( 'description' ) ) : // If a user has filled out their description, show a bio on their entries. ?>
			
			<div id="entry-author-info">
				<div id="author-avatar">
					<?php echo get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'mikegen_author_bio_avatar_size', 60 ) ); ?>
				</div><!-- #author-avatar -->
				<div id="author-description">
					<h2><?php echo __( 'About ' . get_the_author() ); ?></h2>
					<?php the_author_meta( 'description' ); ?>
				</div><!-- #author-description	-->
			</div><!-- #entry-author-info -->
			
		<?php endif; ?>
		
	<?php endif; ?>

	<?php
	/* Since we called the_post() above, we need to
	 * rewind the loop back to the beginning that way
	 * we can run the loop properly, in full.
	 */
	rewind_posts();

	/* Run the loop for the archives page to output the posts.
	 * If you want to overload this in a child theme then include a file
	 * called loop-archive.php and that will be used instead.
	 */
	get_template_part( 'loop', 'archive' );
	?>

</div><!-- #content -->

<?php get_sidebar(); ?>
<?php get_footer(); ?>