<?php
/**
 * Functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists( ) call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists( )) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action( ) or
 * remove_filter( ) and you can attach your own function to the hook.
 *
 * We can remove the parent theme's hook only after it is attached, which means we need to
 * wait until setting up the child theme:
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package WordPress
 */
 
/**
 * Include the theme options
 */
require_once ( get_template_directory( ) . '/theme-options.php' );

/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
if ( ! function_exists( 'mikegen_posted_on' ) ) :
	function mikegen_posted_on( ) 
	{
		$output = '';
		$output .= '<span class="meta-prep meta-prep-author">Posted on</span>';
		$output .= '&nbsp;<span class="entry-date">' . get_the_date( ) . '</span>';
		$output .= '&nbsp;<span class="meta-sep">by</span>';
		$output .= '&nbsp;<span class="author vcard"><a class="url fn n" href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '" title="' . esc_attr__( 'View all posts by ' . get_the_author( )) . '">' . get_the_author( ) . '</a></span>';
		return $output;
	}
endif;

/**
 * Show the categories and tags
 */
if ( ! function_exists( 'mikegen_show_terms' ) ) :
	function mikegen_show_terms( ) 
	{
		$output = '';
		$output .= '<span class="term-links">';
		if ( count( get_the_category( ) ) > 0 ) : 
			$output .= '<span class="cat-links">';
			$output .= __('Categories: ' . get_the_category_list( ', ' ));
			$output .= '</span>';
		endif;
		if ( count( get_the_tags( ) ) > 0 && strlen ( get_the_tag_list() ) > 0 ) : 
			$output .= '<span class="tag-links">';
			$output .= __('Tags: ' . get_the_tag_list( '', ', ', ''));
			$output .= '</span>';
		endif; 
		$output .= '</span>';
		return $output;
	}
endif;

/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own mikegen_comment( ), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments( ) for displaying the comments.
 *
 * @since MikeGen 1.0
 */ 
if ( ! function_exists( 'mikegen_comment' ) ) :
	
	function mikegen_comment( $comment, $args, $depth ) 
	{
		$GLOBALS['comment'] = $comment;
		$output = '';
		$class_array = get_comment_class( );
		$comment_classes = '';
		foreach ($class_array as $key => $value):
			$comment_classes .= $value . ' ';
		endforeach;
		$comment_classes = trim($comment_classes);
		$output .= '<li class="' . $comment_classes . '" id="li-comment-' . get_comment_ID( ) . '">';
		$output .= '<div id="comment-' . get_comment_ID( ) . '">';
		$output .= '<div class="comment-meta">';
		$output .= '<div class="comment-avatar">';
		$output .= $comment->comment_type == 'pingback' || $comment->comment_type == 'trackback' ? '<img src="' . get_bloginfo('template_directory') . '/images/pingback.jpg" alt="" width="40" height="40" />' : get_avatar( $comment, 40 );
		$output .= '</div>';
		$output .= '<div class="comment-author">';
		$output .= $comment->comment_type == 'pingback' ? __('Pingback') : $comment->comment_type == 'trackback' ? __('Trackback') : '';
		$output .= $comment->comment_type !== 'pingback' && $comment->comment_type !== 'trackback' ? get_comment_author_link( ) : '';
		$output .= '</div>';
		$output .= '<div class="comment-date"><a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '">' . get_comment_date( ) . ' at ' . get_comment_time( ) . '</a></div>';
		$output .= '</div><!-- .comment-meta -->';
		if ( $comment->comment_approved == '0' ) : 
			$output .= '<h4 class="comment-awaiting-moderation">' . __('Your comment is awaiting moderation.') . '</h4>';
		endif;
		$output .= '<div class="comment-body">';
		$output .= $comment->comment_type == 'pingback' || $comment->comment_type == 'trackback' ? get_comment_author_link( ) . '&nbsp;&#8212;&nbsp;' : '';
		$output .= nl2br(get_comment_text( ));
		$output .= '</div>';
		$output .= '</div><!-- #comment-## -->';
		$output .= '</li>';
		echo $output;
	}
endif;

/**
 * Register widgetized areas, including two sidebars and four widget-ready columns in the footer.
 *
 * To override mikegen_widgets_init( ) in a child theme, remove the action hook and add your own
 * function tied to the init hook.
 *
 * @since MikeGen 1.0
 * @uses register_sidebar
 */
function mikegen_widgets_init( ) {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'mikegen' ),
		'id' => 'sidebar',
		'description' => __( 'The main sidebar area', 'mikegen' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'mikegen_widgets_init' );

/**
 * Register the navigation menus
 */
if ( function_exists( 'register_nav_menus' ) ):
	register_nav_menus(
		array(
			'top-navigation' => 'Top Navigation',
			'footer-navigation' => 'Footer Navigation'
		)
	);
endif;

/**
 * Truncate text
 */
function truncate($string, $limit, $break=" ", $pad="...") 
{ 
	// return with no change if string is shorter than $limit 
	if(strlen($string) <= $limit) return $string; 
	$string = substr($string, 0, $limit); 
	if(false !== ($breakpoint = strrpos($string, $break))): 
		$string = substr($string, 0, $breakpoint); 
	endif; 
	return $string . $pad;
}

/**
 * Enable featured image / thumbnails
 */
add_theme_support( 'post-thumbnails', array( 'post','page'));

