<?php
/**
 * The loop that displays posts.
 *
 * The loop displays the posts and the post content.  See
 * http://codex.wordpress.org/The_Loop to understand it and
 * http://codex.wordpress.org/Template_Tags to understand
 * the tags used in it.
 *
 * This can be overridden in child themes with loop.php or
 * loop-template.php, where 'template' is the loop context
 * requested by a template. For example, loop-index.php would
 * be used if it exists and we ask for the loop with:
 * <code>get_template_part( 'loop', 'index' );</code>
 *
 * @package WordPress
 * @subpackage MikeGen
 * @since MikeGen 1.0
 */
?>

<?php rewind_posts( ); ?>

<?php while ( have_posts( ) ) : the_post( ); ?>

	<div id="post-<?php the_ID( ); ?>" <?php post_class( ); ?>>
		
		<?php if ( is_single( ) ): ?>
		
			<h2 class="entry-title">
				<?php the_title( ); ?>
			</h2>
			
			<div class="entry-meta">
				<?php echo mikegen_posted_on( ); ?>
				<?php echo mikegen_show_terms( ); ?>
				<div class="entry-comments">
					<a href="<?php comments_link(); ?>" title="Responses to <?php the_title;?>">
						<?php echo _n( '1 Comment', number_format_i18n( get_comments_number( )) . ' Comments', get_comments_number( ) );?>
					</a>
				</div>
			</div><!-- .entry-meta -->
			
			<div class="entry-content">
				<?php the_content( ); ?>
			</div><!-- .entry-content -->
			
			<div class="entry-meta">
				<?php echo mikegen_posted_on( ); ?>
				<?php echo mikegen_show_terms( ); ?>
			</div><!-- .entry-meta -->
			
			<?php comments_template( '', true ); ?>
		
		<?php elseif ( is_page( ) ): ?>
		
			<h2 class="entry-title">
				<?php the_title( ); ?>
			</h2>
			
			<div class="entry-content">
				<?php the_content( ); ?>
			</div><!-- .entry-content -->
			
		<?php elseif ( is_archive( ) || is_search( ) ): ?>
			
			<?php if ( get_post_thumbnail_id($post->ID) ):?>	
				<?php
				$thumb_id = get_post_thumbnail_id($post->ID);
				$image_attributes = wp_get_attachment_image_src( $thumb_id, 'thumbnail' ); 
				?>
				<div class="thumb-wrap">
					<img src="<?php echo $image_attributes[0]; ?>" alt="<?php the_title( );?>" width="126" height="126" />
				</div>
			<?php endif; ?>
	
			<?php echo ( get_post_thumbnail_id($post->ID) ) ? '<div class="content-wrap">' : ''; ?>

			<h3 class="entry-title">
				<a href="<?php the_permalink( ); ?>" title="<?php echo esc_attr__( 'Permalink to ' . the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title( ); ?></a>
			</h3>
			
			<div class="entry-meta">
				<?php echo mikegen_posted_on( ); ?>
				<?php if (get_comments_number( ) > 0): ?>
					<span class="sep">&nbsp;&#8212;&nbsp;</span>
					<a href="<?php comments_link(); ?>">
						<?php echo _n( '1 Comment', number_format_i18n( get_comments_number( )) . ' Comments', get_comments_number( ) );?>
					</a>
				<?php endif; ?>
			</div><!-- .entry-meta -->
			
			<div class="entry-summary">
				<?php echo truncate( get_the_excerpt( ), 280, ' ', ' [...]' ); ?>
			</div><!-- .entry-summary -->
			
			<?php echo ( get_post_thumbnail_id($post->ID) && !is_single( ) && !is_page( ) ) ? '</div>' : ''; ?>
			
		<?php else: ?>
		
			<h2 class="entry-title">
				<a href="<?php the_permalink( ); ?>" title="<?php echo esc_attr__( 'Permalink to ' . the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title( ); ?></a>
			</h2>
			
			<div class="entry-meta">
				<?php echo mikegen_posted_on( ); ?>
				<?php echo mikegen_show_terms( ); ?>
				<?php if (get_comments_number( ) > 0): ?>
					<a href="<?php comments_link(); ?>">
						<?php echo _n( '1 Comment', number_format_i18n( get_comments_number( )) . ' Comments', get_comments_number( ) );?>
					</a>
				<?php endif; ?>
			</div><!-- .entry-meta -->
			
			<div class="entry-content">
				<?php the_content( ); ?>
			</div><!-- .entry-content -->
			
		<?php endif; ?>
		
	</div><!-- #post -->

<?php endwhile; // End the loop. Whew. ?>

<?php if (  $wp_query->max_num_pages > 1 ) : ?>

	<div class="page-navigation">
		<div class="nav-previous">
			<?php next_posts_link( __( '&#9664; Older posts' ) ); ?>
		</div>
		<div class="nav-next">
			<?php previous_posts_link( __( 'Newer posts &#9654;' ) ); ?>
		</div>
	</div><!-- .page-navigation -->
	
<?php endif; ?>
