<?php

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function theme_options_init( )
{
	register_setting( 'mikegen_options', 'mikegen_theme_options', 'theme_options_validate' );
}

/**
 * Load up the menu page
 */
function theme_options_add_page( )
{
	add_theme_page( __( 'Theme Options', 'mikegen' ), __( 'Theme Options', 'mikegen' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );
}

/**
 * Create the options page
 */
function theme_options_do_page( ) 
{

	global $select_options, $radio_options;
	
	if ( ! isset( $_REQUEST['settings-updated'] ) ):
		$_REQUEST['settings-updated'] = false;
	endif;
	?>
	
	<div class="wrap">
	
		<?php 
		screen_icon( ); 
		echo '<h2>' . get_current_theme( ) . __( ' Theme Options', 'mikegen' ) . '</h2>'; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
			<div class="updated fade"><p><strong><?php echo __( 'Options saved', 'mikegen' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'mikegen_options' ); ?>
			<?php $options = get_option( 'mikegen_theme_options' ); ?>

			<table class="form-table">

				<tr valign="top">
					<th scope="row"><?php echo __( 'Logo URL', 'mikegen' ); ?></th>
					<td>
						<input id="mikegen_theme_options[mikegen_logo]" class="regular-text" type="text" name="mikegen_theme_options[mikegen_logo]" value="<?php esc_attr_e( $options['mikegen_logo'] ); ?>" />
						<label class="description" for="mikegen_theme_options[mikegen_logo]"><?php echo __( '<br />Enter the full URL of the logo you would like to use (e.g. http://www.mysite.com/images/logo.png).  A transparent PNG file is recommended.', 'mikegen' ); ?></label>
					</td>
				</tr>
				
				<tr valign="top">
					<th scope="row"><?php echo __( 'Top Search Bar', 'mikegen' ); ?></th>
					<td>
						<input id="mikegen_theme_options[mikegen_topsearch]" name="mikegen_theme_options[mikegen_topsearch]" type="checkbox" value="1" <?php checked( '1', $options['mikegen_topsearch'] ); ?> />
						<label class="description" for="mikegen_theme_options[mikegen_topsearch]"><?php echo __( 'Check this box if you would like a search box in the top navigation bar.', 'mikegen' ); ?></label>
					</td>
				</tr>

				<tr valign="top">
					<th scope="row"><?php echo __( 'Footer Search Bar', 'mikegen' ); ?></th>
					<td>
						<input id="mikegen_theme_options[mikegen_footersearch]" name="mikegen_theme_options[mikegen_footersearch]" type="checkbox" value="1" <?php checked( '1', $options['mikegen_footersearch'] ); ?> />
						<label class="description" for="mikegen_theme_options[mikegen_footersearch]"><?php echo __( 'Check this box if you would like a search box in the footer navigation.', 'mikegen' ); ?></label>
					</td>
				</tr>
	
			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php echo __( 'Save Options', 'mikegen' ); ?>" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function theme_options_validate( $input ) {

	// Our checkbox value is either 0 or 1
	if ( ! isset( $input['topsearch'] ) ):
		$input['topsearch'] = null;
	endif;
	$input['topsearch'] = ( $input['topsearch'] == 1 ? 1 : 0 );
	
	// Our checkbox value is either 0 or 1
	if ( ! isset( $input['footersearch'] ) ):
		$input['footersearch'] = null;
	endif;
	$input['footersearch'] = ( $input['footersearch'] == 1 ? 1 : 0 );

	// Say our text option must be safe text with no HTML tags
	$input['logo'] = wp_filter_nohtml_kses( $input['logo'] );

	return $input;
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/